from django import template
from waliki.plugins import get_extra_page_actions

register = template.Library()


@register.inclusion_tag('waliki/extra_page_actions.html')
def extra_page_actions(page):
    return {'page': page, 'extra_page_actions': get_extra_page_actions()}




from waliki.plugins import BasePlugin, register


class GitPlugin(BasePlugin):

    slug = 'git'
    urls_page = ['waliki.git.urls']
    extra_page_actions = [('waliki_history', 'History')]

register(GitPlugin)




from django.core.urlresolvers import reverse
from django.utils.text import slugify


def get_slug(text):
    return '/'.join(slugify(t) for t in text.split('/'))


def get_url(text, **kwargs):
    return reverse('waliki_detail', args=(get_slug(text),))
